Learn R Programming

photobiologyPlants (version 0.4.3)

B_G: Calculate B:G photon ratio from spectral irradiance.

Description

This function returns the blue:green photon ratio of a light source spectrum.

Usage

B_G(spct, std = "Sellaro", use.cached.mult = FALSE, use.hinges = TRUE)

Value

a single numeric nondimensional value giving the B:G photon ratio, with name attribute set to the name of the wavebands, with "(q:q)" appended.

Arguments

spct

an object of class "source.spct"

std

select which definition of blue and green should be used, defaults to "Sellaro"

use.cached.mult

logical indicating whether multiplier values should be cached between calls

use.hinges

logical indicating whether to use hinges to reduce interpolation errors

See Also

link[photobiologyWavebands]{Blue}, link[photobiologyWavebands]{Green}.

Examples

Run this code
B_G(sun.spct)

Run the code above in your browser using DataLab