Learn R Programming

photobiologyPlants (version 0.6.2)

D_water: Diffusion coefficients in air

Description

Diffusion coefficients of water and carbon dioxide in excess air as a function of temperature.

Usage

D_water(temperature)

D_CO2(temperature)

Value

A numeric vector of the same length as temperature containing diffusion coefficients expressed in \(m^2\,s^{-1}\). NA is returned silently for off-range arguments passed to temperature.

Arguments

temperature

numeric Temperature [\(^{\circ}C\)], in the range -7 to 47 \(^{\circ}C\).

Details

Implemented as interpolating splines from tabulated data.

References

Monteith, J. L. and Unsworth M. H. (2008) Principles of Environmental Physics (3 ed.) Academic Press-Elsevier. ISBN: 978-0-12-505103-3. See Table A.3.

Examples

Run this code
D_water(23)
D_water(c(10, 12, 15, 100))

D_CO2(11)

Run the code above in your browser using DataLab