Learn R Programming

photobiologyPlants (version 0.6.2)

PQ_redox_state: Redox state of the plastoquinone pool

Description

Estimate the redox state of the plastoquinone (PQ) pool from spectral irradiance.

Usage

PQ_redox_state(
  light.spct,
  coefs.spct = photobiologyPlants::PS1_PS2_k.spct,
  w.band = photobiologyWavebands::PAR(),
  force.to.range = TRUE,
  ...
)

# S3 method for default PQ_redox_state( light.spct, coefs.spct = photobiologyPlants::PS1_PS2_k.spct, w.band = photobiologyWavebands::PAR(), force.to.range = TRUE, ... )

# S3 method for source_spct PQ_redox_state( light.spct, coefs.spct = photobiologyPlants::PS1_PS2_k.spct, w.band = photobiologyWavebands::PAR(), force.to.range = TRUE, return.tb = !is.null(attr2tb), attr2tb = NULL, ... )

# S3 method for source_mspct PQ_redox_state( light.spct, coefs.spct = photobiologyPlants::PS1_PS2_k.spct, w.band = photobiologyWavebands::PAR(), force.to.range = TRUE, return.tb = TRUE, attr2tb = NULL, idx = "spct.idx", ..., .parallel = FALSE, .paropts = NULL )

Value

A numeric vector, with one value for each spectrum in the input, or a data frame.

Arguments

light.spct

A source_spct object or a source_mspct object.

coefs.spct

A generic_spct object containing the coefficients of the fitted model. Defaults to those in Mattila et al. (2020).

w.band

A waveband object setting the waveband used for scaling each the spectral irradiance(s) in light.spct. Defaults to PAR as used in Mattila et al. (2020).

force.to.range

logical If TRUE, convert negative values into zero.

...

currently ignored.

return.tb

logical If TRUE force return of a data frame for a single spectrum, to match the returned class for collections of spectra.

attr2tb

character vector, see add_attr2tb the syntax for attr2tb passed as is to formal parameter col.names.

idx

character Name of the column with the names of the members of the collection of spectra.

.parallel

if TRUE, apply function in parallel, using parallel backend provided by foreach

.paropts

a list of additional options passed into the foreach function when parallel computation is enabled. This is important if (for example) your code relies on external data or packages: use the .export and .packages arguments to supply them so that all cluster nodes have the correct environment set up for computing.

Details

The computations follow the procedure in Mattila et al. (2020). The spectrum in light.spct is re-expressed by interpolation to the wavelengths from coefs.spct. As in Mattila et al. (2020) the state is expressed as percent of the PQ pool that is reduced. If the result of the computation is used in a publication, please, cite both Mattila et al. (2020) and this R package.

References

Mattila H, Khorobrykh S, Hakala-Yatkin M, Havurinne V, Kuusisto I, Antal T, Tyystjärvi T, Tyystjärvi E. 2020. Action spectrum of the redox state of the plastoquinone pool defines its function in plant acclimation. The Plant Journal 104, 1088–1104. tools:::Rd_expr_doi("10.1111/tpj.14983").

Examples

Run this code

PQ_redox_state(sun.spct) # PAR is default for scaling
PQ_redox_state(sun.spct, w.band = c(370, 730)) # scaling with wavelength range
PQ_redox_state(sun.spct, attr2tb = "what.measured")
PQ_redox_state(white_led.source_spct)
PQ_redox_state(sun_evening.mspct)
PQ_redox_state(sun_evening.mspct, attr2tb = "when.measured")
PQ_redox_state(sun_evening.spct)

Run the code above in your browser using DataLab