Learn R Programming

photobiologyPlants (version 0.6.2)

Pfr_Ptot: Calculate phytochrome photoequilibrium

Description

Calculate the phytochrome photoequilibrium for monochromatic light from its wavelength or from a spectrum expressed as spectral irradiance.

Usage

Pfr_Ptot(x, ...)

# S3 method for default Pfr_Ptot(x, ...)

# S3 method for numeric Pfr_Ptot(x, spct.out = length(x) > 20, ...)

# S3 method for source_spct Pfr_Ptot(x, return.tb = !is.null(attr2tb), attr2tb = NULL, ..., na.rm = FALSE)

# S3 method for source_mspct Pfr_Ptot( x, return.tb = TRUE, attr2tb = NULL, ..., na.rm = FALSE, idx = "spct.idx", .parallel = FALSE, .paropts = NULL )

Value

When input is spectral data, a numeric vector of values giving the \(P_{fr} / P_{tot}\) or a data frame are returned, possibly with attributes extracted from the spectral objects as additional columns. When input is a numeric vector of wavelengths, the returned object is either a numeric vector or a generic_spct object with giving the \(P_{fr} / P_{tot}\) for each wavelength in the input.

Arguments

x

an R object. A numeric vector

...

currently ignored.

spct.out

logical Flag indicating if the returned object should be of class response_spct instead of numeric.

return.tb

logical If TRUE force return of a data frame for a single spectrum, to match the returned class for collections of spectra.

attr2tb

character vector, see add_attr2tb() the syntax for attr2tb passed as is to formal parameter col.names.

na.rm

logical. If TRUE link[stats]{na.omit} is first called on x.

idx

character Name of the column with the names of the members of the collection of spectra.

.parallel

if TRUE, apply function in parallel, using parallel backend provided by foreach

.paropts

a list of additional options passed into the foreach function when parallel computation is enabled. This is important if (for example) your code relies on external data or packages: use the .export and .packages arguments to supply them so that all cluster nodes have the correct environment set up for computing.

Details

The calculations are based on data describing the photochemical constants for the plant photoreceptor phytochrome measured in vitro and available for wavelengths in the range 380 nm to 770 nm as published by Mancinelli (1994). For reliable estimates of \(P_{fr} / P_{tot}\) from spectral irradiance, the spectrum should cover all these wavelengths with reasonably high wavelength resolution.

Two approaches are possible, using wavelength for monochromatic radiation or spectral irradiance data. Spectral irradiance data are accepted either as individual spectra or collections of spectra.

References

Mancinelli, A.L. (1994) The physiology of phytochrome action. In Photomorphogenesis in plants, 2nd edition. R.E. Kendrick and G.H.M. Kronenberg, eds. Kluwer Academic Publishers, Dordrecht, pp. 211-269. ISBN 978-0-7923-2551-2 (print), 978-94-011-1884-2 (on-line). tools:::Rd_expr_doi("10.1007/978-94-011-1884-2_10")

See Also

Other phytochrome-related functions and data: PHYs.mspct, Pfr_Ptot_R_FR(), Phy_Sigma(), Phy_Sigma_FR(), Phy_Sigma_R(), Phy_reaction_rates()

Examples

Run this code
# monochromatic light
Pfr_Ptot(620) # one wavelength in nm
Pfr_Ptot(c(570, 600, 630, 660, 690, 735, 760)) # six wavelengths
# spectral irradiance
Pfr_Ptot(sun.spct) # one spectrum
Pfr_Ptot(sun.spct, attr2tb = "when.measured")
Pfr_Ptot(sun_evening.spct) # five spectra
Pfr_Ptot(sun_evening.mspct)
Pfr_Ptot(sun_evening.mspct, attr2tb = "when.measured")

Run the code above in your browser using DataLab