Phy_Sigma_FR: Pfr Sigma as a function of wavelength
Description
Pfr Sigma as a function of wavelength, calculated by interpolatio from data
for Type I Phytochrome as compiled by Mancinelli (xxxx).
Usage
Phy_Sigma_FR(w.length, use.cached.mult = FALSE)
Arguments
w.length
numeric array of wavelength (nm)
use.cached.mult
logical ignored
Value
a numeric array with values for Sigma
References
Mancinelli, A.L. (1994) The physiology of phytochrome action. In
Photomorphogenesis in plants, 2nd edition. R.E. Kendrick and G.H.M.
Kronenberg, eds. Kluwer Academic Publishers, Dordrecht, pp. 211-269. ISBN
978-0-7923-2551-2 (print), 978-94-011-1884-2 (on-line).
DOI
10.1007/978-94-011-1884-2_10