Learn R Programming

photobiologyPlants (version 0.4.3)

R_FR: Calculate R:FR photon ratio from spectral irradiance.

Description

This function returns the red:far-red photon ratio of a light source spectrum.

Usage

R_FR(spct, std = "Smith10", use.cached.mult = FALSE, use.hinges = TRUE)

Value

a single numeric nondimensional value giving the R:FR photon ratio, with name attribute set to the name of the wavebands, with "(q:q)" appended.

Arguments

spct

an object of class "source.spct"

std

select which definition of red and far-red should be used, defaults to "Smith"

use.cached.mult

logical indicating whether multiplier values should be cached between calls

use.hinges

logical indicating whether to use hinges to reduce interpolation errors

See Also

link[photobiologyWavebands]{Red}, link[photobiologyWavebands]{Far_red}.

Examples

Run this code
R_FR(sun.spct)

Run the code above in your browser using DataLab