powered by
This function returns the UVA2:UV photon ratio of a light source spectrum.
UVA2_UV(spct, std = "CIE", use.cached.mult = FALSE, use.hinges = TRUE)
a single numeric nondimensional value giving the UVA:UV photon ratio, with name attribute set to the name of the wavebands, with "(q:q)" appended.
an object of class "source.spct"
select which definition of UVA1 should be used, defaults to "CIE". For UV "ISO" is always used.
logical indicating whether multiplier values should be cached between calls
logical indicating whether to use hinges to reduce interpolation errors
link[photobiologyWavebands]{UV}, link[photobiologyWavebands]{UVA}.
link[photobiologyWavebands]{UV}
link[photobiologyWavebands]{UVA}
UVA2_UV(sun.spct)
Run the code above in your browser using DataLab