powered by
This function returns the UVA:UV photon ratio of a light source spectrum.
UVA_UV(spct, std = "ISO", use.cached.mult = FALSE, use.hinges = TRUE)
a single numeric nondimensional value giving the UVA:UV photon ratio, with name attribute set to the name of the wavebands, with "(q:q)" appended.
an object of class "source.spct"
select which definition of UVB and UV should be used, defaults to "ISO"
logical indicating whether multiplier values should be cached between calls
logical indicating whether to use hinges to reduce interpolation errors
link[photobiologyWavebands]{UVA}, link[photobiologyWavebands]{UV}.
link[photobiologyWavebands]{UVA}
link[photobiologyWavebands]{UV}
UVA_UV(sun.spct)
Run the code above in your browser using DataLab