Learn R Programming

photobiologyPlants (version 0.4.3)

UVAsw_UV: Calculate UVAsw:UV photon ratio from spectral irradiance.

Description

This function returns the UVAsw:UV photon ratio of a light source spectrum.

Usage

UVAsw_UV(spct, std = "plants", use.cached.mult = FALSE, use.hinges = TRUE)

Value

a single numeric nondimensional value giving the UVA:UV photon ratio, with name attribute set to the name of the wavebands, with "(q:q)" appended.

Arguments

spct

an object of class "source.spct"

std

select which definition of UVAsw should be used, defaults to "plants". For UV "ISO" is always used.

use.cached.mult

logical indicating whether multiplier values should be cached between calls

use.hinges

logical indicating whether to use hinges to reduce interpolation errors

See Also

link[photobiologyWavebands]{UVA}, link[photobiologyWavebands]{UV}.

Examples

Run this code
UVAsw_UV(sun.spct)

Run the code above in your browser using DataLab