Learn R Programming

photobiologyPlants (version 0.4.3)

UV_PAR: Calculate UV:PAR photon ratio from spectral irradiance.

Description

This function returns the UV:PAR photon ratio of a light source spectrum.

Usage

UV_PAR(spct, std = "ISO", use.cached.mult = FALSE, use.hinges = TRUE)

Value

a single numeric nondimensional value giving the UV:PAR photon ratio, with name attribute set to the name of the wavebands, with "(q:q)" appended.

Arguments

spct

an object of class "source.spct"

std

select which definition of UV should be used, defaults to "ISO"

use.cached.mult

logical indicating whether multiplier values should be cached between calls

use.hinges

logical indicating whether to use hinges to reduce interpolation errors

See Also

link[photobiologyWavebands]{UV}, link[photobiologyWavebands]{PAR}.

Examples

Run this code
UV_PAR(sun.spct)

Run the code above in your browser using DataLab