Learn R Programming

photobiologyPlants (version 0.6.2)

rs_from_size: Stomatal conductance from sizes and density

Description

Computations based on mass transfer through pores.

Usage

rs_from_size(length, width = length, depth, num = 1, D)

gs_from_size(length, width = length, depth, num = 1, D)

gs_w_from_size(length, width = length, depth, num = 1, temperature)

gs_c_from_size(length, width = length, depth, num = 1, temperature)

Value

A numeric vector of resistances expressed in \(s\,m^{-1}\)

or \(s\,mol^{-1}\), or of conductances expressed in \(m\,s^{-1}\) or in \(mol\,m^{-2}\,s^{-1}\) when the density expressed in estomata per \(m^2\)

is passed as argument to n. With the default of n = 1 the diffusive conductance per individual pore is returned expressed, e.g., for molar conductance, in \(mol\,s-1\).

Arguments

length, width

numeric "Length" and "width" of the stomatal opening, i.e., the major and minor diameters of the ellipse describing the stomatal pore's mean cross section [\(m\)].

depth

numeric The depth (or diffusion path length) of the stomatal pore [\(m\)].

num

numeric Number of stomata per unit area [\(m^{-2}\)].

D

numeric Diffusion coefficient of the gas [\(m^2\,s^{-1}\)].

temperature

numeric Leaf temperature. Used to estimate the diffusion coefficient D.

Details

The equation for \(r_s\) from Monteith and Unsworth (2008):

$$r_s = \frac{4(l + \pi\,d / 8)}{\pi\,n\,d^2\,D}$$

is used to compute diffusive resistance in function rs_from_size(), which can be used to obtain diffusive resistance from a known size of a pore with circular or elliptical cross section. The value of D, the diffusion should match that of water vapour or \(CO_2\), and its unit of expression determines the whether the returned value is expressed as the inverse of a volume or molar flux rate.

Functions gs_from_size(), gs_w_from_size() and gs_c_from_size() are convenience wrappers.

Arguments are expected in SI units with no scale multiplier. Enter dimensions in micrometers using scientific notation, e.g., length = 20e-6 for a pore length of \(20\,\mu m\) and n = 10e6 for a density of \(10\,mm^{-2}\).

References

Monteith, J. L. and Unsworth M. H. (2008) Principles of Environmental Physics (3ed) Academic Press-Elsevier. ISBN: 978-0-12-505103-3. See Section 11.4 Mass transfer through pores.

See Also

Functions D_water() and D_CO2() can be used to compute the diffusion coefficients as a function of temperature. In addition function molar_vol() computes the molar volume of an ideal gas as a function of temperature and pressure. Functions gs_mol2vol() and gs_vol2mol() interconvert conductances between molar and volume bases of expression. These functions are used internally in the functions described here.

Examples

Run this code
# a single round stomatal pore
gs_from_size(length = 20e-6, depth = 5e-6, D = D_water(23))

# a single elliptical stomatal pore
gs_from_size(length = 30e-6, width = 10e-6, depth = 5e-6, D = D_water(23))

# 200 circular stomatal pores per mm^2
rs_from_size(length = 5e-6,
             width = 5e-6,
             depth = 10e-6,
             num = 200e6,
             D = D_water(25))

# 50 elliptical stomatal pores per mm^2
rs_from_size(length = 10e-6,
             width = 5-6,
             depth = 20e-6,
             num = 50e6,
             D = D_water(23))

# a single round stomatal pore with dimensions in micrometers
gs_from_size(length = 20, depth = 5, D = D_water(23))

Run the code above in your browser using DataLab