powered by
Convert between stomatal conductances to water vapour and carbon dioxide.
gs_c_from_gs_w(gs_w, temperature = 21)gs_w_from_gs_c(gs_c, temperature = 21)gs_vol2mol(gs, temperature = 21, pressure = 101300)gs_mol2vol(gs_c, temperature = 21, pressure = 101300)
gs_w_from_gs_c(gs_c, temperature = 21)
gs_vol2mol(gs, temperature = 21, pressure = 101300)
gs_mol2vol(gs_c, temperature = 21, pressure = 101300)
A numeric vector of stomatal conductance values expressed as
\(m^2\,s^{-1}\).
numeric Stomatal conductance to water vapour and carbon dioxide [\(m^2\,s^{-1}\)].
numeric Temperature [\(^{\circ}C\)], in the range -7 to 47 \(^{\circ}C\).
numeric Pressure of the gas, e.g., atmospheric pressure [Pa].
These conversions are based on the diffusion coefficients, both of which are looked up based on the temperature.
# example code gs_c_from_gs_w(1/120) gs_vol2mol(1/120)
Run the code above in your browser using DataLab